@@ -36,7 +36,7 @@ tbl_sum.spatial_cubble_df <- function(x){
   x_is_sf <- is_sf(x)
   if (!x_is_sf) {
     coord_vars <- coords(x)
-    x <- as_tibble(x) %>% sf::st_as_sf(coords = coord_vars)
+    x <- as_tibble(x) |> sf::st_as_sf(coords = coord_vars)
   }
 
   line2 <- glue::glue("[", paste0(sf::st_bbox(x), collapse = ", "), "]")
@@ -79,7 +79,8 @@ tbl_sum.temporal_cubble_df <- function(x){
 
   # line 2: FROM -- TO [BY] HAS_GAP
   if (!is_tsibble(x)) {
-    x_tsibble <- as_tsibble(as_tibble(x), key = key_vars(x), index = index(x))
+    xx <- x # a wired issue raised in issue 21
+    x_tsibble <- as_tsibble(as_tibble(x), key = key_vars(x), index = index(xx))
   } else{
     x_tsibble <- x
   }
