@@ -27,8 +27,8 @@ extract_longlat <- function(data){
   lat_name <- c("lat", "latitude")
   if (any(dims %in% lat_name)) lat_idx <- which(dims %in% lat_name)
 
-  long <- ncdf4::ncvar_get(data, dims[long_idx]) %>% as.vector()
-  lat <- ncdf4::ncvar_get(data, dims[lat_idx]) %>% as.vector()
+  long <- ncdf4::ncvar_get(data, dims[long_idx]) |> as.vector()
+  lat <- ncdf4::ncvar_get(data, dims[lat_idx]) |> as.vector()
 
   list(long = long, lat = lat)
 
@@ -68,8 +68,8 @@ parse_time <- function(tstring){
   if (length(seg_n) == 3) {
     dttm <- stringr::str_remove(tstring, seg_n[3])
     tzone_string <- as.numeric(stringr::str_replace(seg_n[3], ":", "."))
-    tzone_std <- tzone_list %>%
-      dplyr::filter(as.numeric(.data$utc_offset_h) == tzone_string) %>%
+    tzone_std <- tzone_list |> 
+      dplyr::filter(as.numeric(.data$utc_offset_h) == tzone_string) |> 
       dplyr::pull(.data$tz_name)
 
     if (length(tzone_std) == 0){
